/************************************************************************
 *   IRC - Internet Relay Chat, m_core/m_clabort.c
 *   This file is copyright (C) 2001 Andrew Suffield
 *                                    <asuffield@users.sourceforge.net>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#include "ircd.h"
#include "common.h"
#include "numeric.h"
#include "irc_string.h"
#include "send.h"
#include "umodes.h"
#include "msg.h"
#include "handlers.h"
#include "channel.h"
#include "client.h"

#include <string.h>

int m_clabort(struct Client *, struct Client *, int, char **);

struct Message clabort_msgtab = {
  "CLABORT", 0, 0, 0, MFLG_SLOW, 0,
  {m_unregistered, m_ignore, m_clabort},
  NULL, NULL
};

/*
 * m_clabort
 * Abort the channel lock process, unlock all channels
 * parv[0] == originator of abort (near-side server which killed the link)
 */
int
m_clabort(struct Client *cptr, struct Client *sptr, int parc, char *parv[])
{
  struct Channel *chptr;

  for (chptr = channel; chptr; chptr = chptr->nextch)
    {
      chptr->frozen_by = NULL;
      if (!chptr->users)
	sub1_from_channel(chptr);
    }

  sendto_ops_flag(UMODE_SERVNOTICE, "Channel lock aborted by %s", parv[0]);

  burst_in_progress = NULL;
  already_clacked = 0;
  return 0;
}
